==> synfigstudio-0.64.1p0.tgz: include/synfigapp-0.0/synfigapp/waypointsetsmart.h <==
/* === S Y N F I G ========================================================= */
/*!	\file waypointsetsmart.h
**	\brief Template File
**
**	$Id$
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**
**	This package is free software; you can redistribute it and/or
**	modify it under the terms of the GNU General Public License as
**	published by the Free Software Foundation; either version 2 of
**	the License, or (at your option) any later version.
**
**	This package is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**	General Public License for more details.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_APP_ACTION_WAYPOINTSETSMART_H
#define __SYNFIG_APP_ACTION_WAYPOINTSETSMART_H

/* === H E A D E R S ======================================================= */

#include <synfigapp/action.h>
#include <synfigapp/value_desc.h>
#include <synfig/valuenode_animated.h>

#include <list>
#include <set>

/* === M A C R O S ========================================================= */

/* === T Y P E D E F S ===================================================== */

/* === C L A S S E S & S T R U C T S ======================================= */

namespace synfigapp {

namespace Action {

class WaypointSetSmart :
	public Super
{
private:

	synfig::ValueNode_Animated::Handle value_node;
	synfig::Waypoint waypoint;
	//synfig::WaypointModel waypoint_model;
	bool time_set;

	void calc_waypoint();
	void enclose_waypoint(const synfig::Waypoint& waypoint);

	std::set<synfig::Time> times;

public:

	WaypointSetSmart();

	static ParamVocab get_param_vocab();
	static bool is_candidate(const ParamList &x);

	virtual bool set_param(const synfig::String& name, const Param &);
	virtual bool is_ready()const;

	virtual void prepare();

	ACTION_MODULE_EXT
};

}; // END of namespace action
}; // END of namespace studio

/* === E N D =============================================================== */

#endif

==> synfigstudio-1.5.3p3.tgz: include/synfigapp-0.0/synfigapp/waypointsetsmart.h <==
/* === S Y N F I G ========================================================= */
/*!	\file waypointsetsmart.h
**	\brief Template File
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**
**	This file is part of Synfig.
**
**	Synfig is free software: you can redistribute it and/or modify
**	it under the terms of the GNU General Public License as published by
**	the Free Software Foundation, either version 2 of the License, or
**	(at your option) any later version.
**
**	Synfig is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
**	You should have received a copy of the GNU General Public License
**	along with Synfig.  If not, see <https://www.gnu.org/licenses/>.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_APP_ACTION_WAYPOINTSETSMART_H
#define __SYNFIG_APP_ACTION_WAYPOINTSETSMART_H

/* === H E A D E R S ======================================================= */

#include <synfigapp/action.h>
#include <synfigapp/value_desc.h>
#include <synfig/valuenodes/valuenode_animated.h>

#include <list>
#include <set>

/* === M A C R O S ========================================================= */

/* === T Y P E D E F S ===================================================== */

/* === C L A S S E S & S T R U C T S ======================================= */

namespace synfigapp {

namespace Action {

class WaypointSetSmart :
	public Super
{
private:

	synfig::ValueNode_Animated::Handle value_node;
	synfig::Waypoint waypoint;
	ValueDesc value_desc;
	//synfig::WaypointModel waypoint_model;
	bool time_set;

	void calc_waypoint();
	void enclose_waypoint(const synfig::Waypoint& waypoint);
	void redirect_to_value_desc_set_action();

	std::set<synfig::Time> times;

public:

	WaypointSetSmart();

	static ParamVocab get_param_vocab();
	static bool is_candidate(const ParamList &x);

	virtual bool set_param(const synfig::String& name, const Param &);
	virtual bool is_ready()const;

	virtual void prepare();

	ACTION_MODULE_EXT
};

}; // END of namespace action
}; // END of namespace studio

/* === E N D =============================================================== */

#endif
